/*
 * A Bit of Everything
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * API version: 1.0
 * Contact: none@example.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package abe
// ExamplepbsnakeCaseEnum : - value_c: buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE  - value_d: buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE
type ExamplepbsnakeCaseEnum string

// List of examplepbsnake_case_enum
const (
	C_ExamplepbsnakeCaseEnum ExamplepbsnakeCaseEnum = "value_c"
	D_ExamplepbsnakeCaseEnum ExamplepbsnakeCaseEnum = "value_d"
)
