/*
 * Echo Service
 *
 * Echo Service API consists of a single service which returns a message.
 *
 * API version: version not set
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package echo

// DynamicMessage represents a message which can have its structure built dynamically using Struct and Values.
type ExamplepbDynamicMessage struct {
	StructField *interface{} `json:"structField,omitempty"`
	ValueField *interface{} `json:"valueField,omitempty"`
}
