/*
 * Echo Service
 *
 * Echo Service API consists of a single service which returns a message.
 *
 * API version: version not set
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package echo
// ProtobufNullValue : `NullValue` is a singleton enumeration to represent the null value for the `Value` type union.   The JSON representation for `NullValue` is JSON `null`.   - NULL_VALUE: Null value.
type ProtobufNullValue string

// List of protobufNullValue
const (
	NULL_VALUE_ProtobufNullValue ProtobufNullValue = "NULL_VALUE"
)
