/*
 * A Bit of Everything
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * API version: 1.0
 * Contact: none@example.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package abe

type ExamplepbABitOfEverythingRepeated struct {
	PathRepeatedFloatValue []float32 `json:"pathRepeatedFloatValue,omitempty"`
	PathRepeatedDoubleValue []float64 `json:"pathRepeatedDoubleValue,omitempty"`
	PathRepeatedInt64Value []string `json:"pathRepeatedInt64Value,omitempty"`
	PathRepeatedUint64Value []string `json:"pathRepeatedUint64Value,omitempty"`
	PathRepeatedInt32Value []int32 `json:"pathRepeatedInt32Value,omitempty"`
	PathRepeatedFixed64Value []string `json:"pathRepeatedFixed64Value,omitempty"`
	PathRepeatedFixed32Value []int64 `json:"pathRepeatedFixed32Value,omitempty"`
	PathRepeatedBoolValue []bool `json:"pathRepeatedBoolValue,omitempty"`
	PathRepeatedStringValue []string `json:"pathRepeatedStringValue,omitempty"`
	PathRepeatedBytesValue []string `json:"pathRepeatedBytesValue,omitempty"`
	PathRepeatedUint32Value []int64 `json:"pathRepeatedUint32Value,omitempty"`
	PathRepeatedEnumValue []ExamplepbNumericEnum `json:"pathRepeatedEnumValue,omitempty"`
	PathRepeatedSfixed32Value []int32 `json:"pathRepeatedSfixed32Value,omitempty"`
	PathRepeatedSfixed64Value []string `json:"pathRepeatedSfixed64Value,omitempty"`
	PathRepeatedSint32Value []int32 `json:"pathRepeatedSint32Value,omitempty"`
	PathRepeatedSint64Value []string `json:"pathRepeatedSint64Value,omitempty"`
}
