/*
 * A Bit of Everything
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * API version: 1.0
 * Contact: none@example.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package abe
// PathenumsnakeCaseForImport : - value_x: buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE  - value_y: buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE
type PathenumsnakeCaseForImport string

// List of pathenumsnake_case_for_import
const (
	X_PathenumsnakeCaseForImport PathenumsnakeCaseForImport = "value_x"
	Y_PathenumsnakeCaseForImport PathenumsnakeCaseForImport = "value_y"
)
