// Code generated by protoc-gen-go-grpc. DO NOT EDIT.

package examplepb

import (
	context "context"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
// Requires gRPC-Go v1.32.0 or later.
const _ = grpc.SupportPackageIsVersion7

// ServiceBClient is the client API for ServiceB service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
type ServiceBClient interface {
	// ServiceB.MethodOne receives InMessageB and returns OutMessageB
	//
	// Here is the detail explanation about ServiceB.MethodOne.
	MethodOne(ctx context.Context, in *InMessageB, opts ...grpc.CallOption) (*OutMessageB, error)
	// ServiceB.MethodTwo receives OutMessageB and returns InMessageB
	//
	// Here is the detail explanation about ServiceB.MethodTwo.
	MethodTwo(ctx context.Context, in *OutMessageB, opts ...grpc.CallOption) (*InMessageB, error)
}

type serviceBClient struct {
	cc grpc.ClientConnInterface
}

func NewServiceBClient(cc grpc.ClientConnInterface) ServiceBClient {
	return &serviceBClient{cc}
}

func (c *serviceBClient) MethodOne(ctx context.Context, in *InMessageB, opts ...grpc.CallOption) (*OutMessageB, error) {
	out := new(OutMessageB)
	err := c.cc.Invoke(ctx, "/grpc.gateway.examples.internal.examplepb.ServiceB/MethodOne", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *serviceBClient) MethodTwo(ctx context.Context, in *OutMessageB, opts ...grpc.CallOption) (*InMessageB, error) {
	out := new(InMessageB)
	err := c.cc.Invoke(ctx, "/grpc.gateway.examples.internal.examplepb.ServiceB/MethodTwo", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ServiceBServer is the server API for ServiceB service.
// All implementations should embed UnimplementedServiceBServer
// for forward compatibility
type ServiceBServer interface {
	// ServiceB.MethodOne receives InMessageB and returns OutMessageB
	//
	// Here is the detail explanation about ServiceB.MethodOne.
	MethodOne(context.Context, *InMessageB) (*OutMessageB, error)
	// ServiceB.MethodTwo receives OutMessageB and returns InMessageB
	//
	// Here is the detail explanation about ServiceB.MethodTwo.
	MethodTwo(context.Context, *OutMessageB) (*InMessageB, error)
}

// UnimplementedServiceBServer should be embedded to have forward compatible implementations.
type UnimplementedServiceBServer struct {
}

func (UnimplementedServiceBServer) MethodOne(context.Context, *InMessageB) (*OutMessageB, error) {
	return nil, status.Errorf(codes.Unimplemented, "method MethodOne not implemented")
}
func (UnimplementedServiceBServer) MethodTwo(context.Context, *OutMessageB) (*InMessageB, error) {
	return nil, status.Errorf(codes.Unimplemented, "method MethodTwo not implemented")
}

// UnsafeServiceBServer may be embedded to opt out of forward compatibility for this service.
// Use of this interface is not recommended, as added methods to ServiceBServer will
// result in compilation errors.
type UnsafeServiceBServer interface {
	mustEmbedUnimplementedServiceBServer()
}

func RegisterServiceBServer(s grpc.ServiceRegistrar, srv ServiceBServer) {
	s.RegisterService(&ServiceB_ServiceDesc, srv)
}

func _ServiceB_MethodOne_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(InMessageB)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ServiceBServer).MethodOne(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/grpc.gateway.examples.internal.examplepb.ServiceB/MethodOne",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ServiceBServer).MethodOne(ctx, req.(*InMessageB))
	}
	return interceptor(ctx, in, info, handler)
}

func _ServiceB_MethodTwo_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(OutMessageB)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ServiceBServer).MethodTwo(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/grpc.gateway.examples.internal.examplepb.ServiceB/MethodTwo",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ServiceBServer).MethodTwo(ctx, req.(*OutMessageB))
	}
	return interceptor(ctx, in, info, handler)
}

// ServiceB_ServiceDesc is the grpc.ServiceDesc for ServiceB service.
// It's only intended for direct use with grpc.RegisterService,
// and not to be introspected or modified (even as a copy)
var ServiceB_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "grpc.gateway.examples.internal.examplepb.ServiceB",
	HandlerType: (*ServiceBServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "MethodOne",
			Handler:    _ServiceB_MethodOne_Handler,
		},
		{
			MethodName: "MethodTwo",
			Handler:    _ServiceB_MethodTwo_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "examples/internal/proto/examplepb/openapi_merge_b.proto",
}
