// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.27.1
// 	protoc        (unknown)
// source: examples/internal/proto/pathenum/path_enum.proto

package pathenum

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type PathEnum int32

const (
	PathEnum_ABC PathEnum = 0
	PathEnum_DEF PathEnum = 1
)

// Enum value maps for PathEnum.
var (
	PathEnum_name = map[int32]string{
		0: "ABC",
		1: "DEF",
	}
	PathEnum_value = map[string]int32{
		"ABC": 0,
		"DEF": 1,
	}
)

func (x PathEnum) Enum() *PathEnum {
	p := new(PathEnum)
	*p = x
	return p
}

func (x PathEnum) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (PathEnum) Descriptor() protoreflect.EnumDescriptor {
	return file_examples_internal_proto_pathenum_path_enum_proto_enumTypes[0].Descriptor()
}

func (PathEnum) Type() protoreflect.EnumType {
	return &file_examples_internal_proto_pathenum_path_enum_proto_enumTypes[0]
}

func (x PathEnum) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use PathEnum.Descriptor instead.
func (PathEnum) EnumDescriptor() ([]byte, []int) {
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP(), []int{0}
}

// Ignoring lint warnings as this enum type exist to validate proper functionality
// for projects that don't follow these lint rules.
// buf:lint:ignore ENUM_PASCAL_CASE
type SnakeCaseForImport int32

const (
	// buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE
	SnakeCaseForImport_value_x SnakeCaseForImport = 0
	// buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE
	SnakeCaseForImport_value_y SnakeCaseForImport = 1
)

// Enum value maps for SnakeCaseForImport.
var (
	SnakeCaseForImport_name = map[int32]string{
		0: "value_x",
		1: "value_y",
	}
	SnakeCaseForImport_value = map[string]int32{
		"value_x": 0,
		"value_y": 1,
	}
)

func (x SnakeCaseForImport) Enum() *SnakeCaseForImport {
	p := new(SnakeCaseForImport)
	*p = x
	return p
}

func (x SnakeCaseForImport) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (SnakeCaseForImport) Descriptor() protoreflect.EnumDescriptor {
	return file_examples_internal_proto_pathenum_path_enum_proto_enumTypes[1].Descriptor()
}

func (SnakeCaseForImport) Type() protoreflect.EnumType {
	return &file_examples_internal_proto_pathenum_path_enum_proto_enumTypes[1]
}

func (x SnakeCaseForImport) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use SnakeCaseForImport.Descriptor instead.
func (SnakeCaseForImport) EnumDescriptor() ([]byte, []int) {
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP(), []int{1}
}

type MessagePathEnum_NestedPathEnum int32

const (
	MessagePathEnum_GHI MessagePathEnum_NestedPathEnum = 0
	MessagePathEnum_JKL MessagePathEnum_NestedPathEnum = 1
)

// Enum value maps for MessagePathEnum_NestedPathEnum.
var (
	MessagePathEnum_NestedPathEnum_name = map[int32]string{
		0: "GHI",
		1: "JKL",
	}
	MessagePathEnum_NestedPathEnum_value = map[string]int32{
		"GHI": 0,
		"JKL": 1,
	}
)

func (x MessagePathEnum_NestedPathEnum) Enum() *MessagePathEnum_NestedPathEnum {
	p := new(MessagePathEnum_NestedPathEnum)
	*p = x
	return p
}

func (x MessagePathEnum_NestedPathEnum) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (MessagePathEnum_NestedPathEnum) Descriptor() protoreflect.EnumDescriptor {
	return file_examples_internal_proto_pathenum_path_enum_proto_enumTypes[2].Descriptor()
}

func (MessagePathEnum_NestedPathEnum) Type() protoreflect.EnumType {
	return &file_examples_internal_proto_pathenum_path_enum_proto_enumTypes[2]
}

func (x MessagePathEnum_NestedPathEnum) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use MessagePathEnum_NestedPathEnum.Descriptor instead.
func (MessagePathEnum_NestedPathEnum) EnumDescriptor() ([]byte, []int) {
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP(), []int{0, 0}
}

type MessagePathEnum struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *MessagePathEnum) Reset() {
	*x = MessagePathEnum{}
	if protoimpl.UnsafeEnabled {
		mi := &file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *MessagePathEnum) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MessagePathEnum) ProtoMessage() {}

func (x *MessagePathEnum) ProtoReflect() protoreflect.Message {
	mi := &file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MessagePathEnum.ProtoReflect.Descriptor instead.
func (*MessagePathEnum) Descriptor() ([]byte, []int) {
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP(), []int{0}
}

type MessageWithPathEnum struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Value PathEnum `protobuf:"varint,1,opt,name=value,proto3,enum=grpc.gateway.examples.internal.pathenum.PathEnum" json:"value,omitempty"`
}

func (x *MessageWithPathEnum) Reset() {
	*x = MessageWithPathEnum{}
	if protoimpl.UnsafeEnabled {
		mi := &file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *MessageWithPathEnum) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MessageWithPathEnum) ProtoMessage() {}

func (x *MessageWithPathEnum) ProtoReflect() protoreflect.Message {
	mi := &file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MessageWithPathEnum.ProtoReflect.Descriptor instead.
func (*MessageWithPathEnum) Descriptor() ([]byte, []int) {
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP(), []int{1}
}

func (x *MessageWithPathEnum) GetValue() PathEnum {
	if x != nil {
		return x.Value
	}
	return PathEnum_ABC
}

type MessageWithNestedPathEnum struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Value MessagePathEnum_NestedPathEnum `protobuf:"varint,1,opt,name=value,proto3,enum=grpc.gateway.examples.internal.pathenum.MessagePathEnum_NestedPathEnum" json:"value,omitempty"`
}

func (x *MessageWithNestedPathEnum) Reset() {
	*x = MessageWithNestedPathEnum{}
	if protoimpl.UnsafeEnabled {
		mi := &file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *MessageWithNestedPathEnum) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MessageWithNestedPathEnum) ProtoMessage() {}

func (x *MessageWithNestedPathEnum) ProtoReflect() protoreflect.Message {
	mi := &file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MessageWithNestedPathEnum.ProtoReflect.Descriptor instead.
func (*MessageWithNestedPathEnum) Descriptor() ([]byte, []int) {
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP(), []int{2}
}

func (x *MessageWithNestedPathEnum) GetValue() MessagePathEnum_NestedPathEnum {
	if x != nil {
		return x.Value
	}
	return MessagePathEnum_GHI
}

var File_examples_internal_proto_pathenum_path_enum_proto protoreflect.FileDescriptor

var file_examples_internal_proto_pathenum_path_enum_proto_rawDesc = []byte{
	0x0a, 0x30, 0x65, 0x78, 0x61, 0x6d, 0x70, 0x6c, 0x65, 0x73, 0x2f, 0x69, 0x6e, 0x74, 0x65, 0x72,
	0x6e, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2f, 0x70, 0x61, 0x74, 0x68, 0x65, 0x6e,
	0x75, 0x6d, 0x2f, 0x70, 0x61, 0x74, 0x68, 0x5f, 0x65, 0x6e, 0x75, 0x6d, 0x2e, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x12, 0x27, 0x67, 0x72, 0x70, 0x63, 0x2e, 0x67, 0x61, 0x74, 0x65, 0x77, 0x61, 0x79,
	0x2e, 0x65, 0x78, 0x61, 0x6d, 0x70, 0x6c, 0x65, 0x73, 0x2e, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e,
	0x61, 0x6c, 0x2e, 0x70, 0x61, 0x74, 0x68, 0x65, 0x6e, 0x75, 0x6d, 0x22, 0x35, 0x0a, 0x0f, 0x4d,
	0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x22, 0x22,
	0x0a, 0x0e, 0x4e, 0x65, 0x73, 0x74, 0x65, 0x64, 0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d,
	0x12, 0x07, 0x0a, 0x03, 0x47, 0x48, 0x49, 0x10, 0x00, 0x12, 0x07, 0x0a, 0x03, 0x4a, 0x4b, 0x4c,
	0x10, 0x01, 0x22, 0x5e, 0x0a, 0x13, 0x4d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x57, 0x69, 0x74,
	0x68, 0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x12, 0x47, 0x0a, 0x05, 0x76, 0x61, 0x6c,
	0x75, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x31, 0x2e, 0x67, 0x72, 0x70, 0x63, 0x2e,
	0x67, 0x61, 0x74, 0x65, 0x77, 0x61, 0x79, 0x2e, 0x65, 0x78, 0x61, 0x6d, 0x70, 0x6c, 0x65, 0x73,
	0x2e, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2e, 0x70, 0x61, 0x74, 0x68, 0x65, 0x6e,
	0x75, 0x6d, 0x2e, 0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x52, 0x05, 0x76, 0x61, 0x6c,
	0x75, 0x65, 0x22, 0x7a, 0x0a, 0x19, 0x4d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x57, 0x69, 0x74,
	0x68, 0x4e, 0x65, 0x73, 0x74, 0x65, 0x64, 0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x12,
	0x5d, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x47,
	0x2e, 0x67, 0x72, 0x70, 0x63, 0x2e, 0x67, 0x61, 0x74, 0x65, 0x77, 0x61, 0x79, 0x2e, 0x65, 0x78,
	0x61, 0x6d, 0x70, 0x6c, 0x65, 0x73, 0x2e, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2e,
	0x70, 0x61, 0x74, 0x68, 0x65, 0x6e, 0x75, 0x6d, 0x2e, 0x4d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65,
	0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x2e, 0x4e, 0x65, 0x73, 0x74, 0x65, 0x64, 0x50,
	0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x2a, 0x1c,
	0x0a, 0x08, 0x50, 0x61, 0x74, 0x68, 0x45, 0x6e, 0x75, 0x6d, 0x12, 0x07, 0x0a, 0x03, 0x41, 0x42,
	0x43, 0x10, 0x00, 0x12, 0x07, 0x0a, 0x03, 0x44, 0x45, 0x46, 0x10, 0x01, 0x2a, 0x31, 0x0a, 0x15,
	0x73, 0x6e, 0x61, 0x6b, 0x65, 0x5f, 0x63, 0x61, 0x73, 0x65, 0x5f, 0x66, 0x6f, 0x72, 0x5f, 0x69,
	0x6d, 0x70, 0x6f, 0x72, 0x74, 0x12, 0x0b, 0x0a, 0x07, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x5f, 0x78,
	0x10, 0x00, 0x12, 0x0b, 0x0a, 0x07, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x5f, 0x79, 0x10, 0x01, 0x42,
	0x4c, 0x5a, 0x4a, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x67, 0x72,
	0x70, 0x63, 0x2d, 0x65, 0x63, 0x6f, 0x73, 0x79, 0x73, 0x74, 0x65, 0x6d, 0x2f, 0x67, 0x72, 0x70,
	0x63, 0x2d, 0x67, 0x61, 0x74, 0x65, 0x77, 0x61, 0x79, 0x2f, 0x76, 0x32, 0x2f, 0x65, 0x78, 0x61,
	0x6d, 0x70, 0x6c, 0x65, 0x73, 0x2f, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2f, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x2f, 0x70, 0x61, 0x74, 0x68, 0x65, 0x6e, 0x75, 0x6d, 0x62, 0x06, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x33,
}

var (
	file_examples_internal_proto_pathenum_path_enum_proto_rawDescOnce sync.Once
	file_examples_internal_proto_pathenum_path_enum_proto_rawDescData = file_examples_internal_proto_pathenum_path_enum_proto_rawDesc
)

func file_examples_internal_proto_pathenum_path_enum_proto_rawDescGZIP() []byte {
	file_examples_internal_proto_pathenum_path_enum_proto_rawDescOnce.Do(func() {
		file_examples_internal_proto_pathenum_path_enum_proto_rawDescData = protoimpl.X.CompressGZIP(file_examples_internal_proto_pathenum_path_enum_proto_rawDescData)
	})
	return file_examples_internal_proto_pathenum_path_enum_proto_rawDescData
}

var file_examples_internal_proto_pathenum_path_enum_proto_enumTypes = make([]protoimpl.EnumInfo, 3)
var file_examples_internal_proto_pathenum_path_enum_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_examples_internal_proto_pathenum_path_enum_proto_goTypes = []interface{}{
	(PathEnum)(0),                       // 0: grpc.gateway.examples.internal.pathenum.PathEnum
	(SnakeCaseForImport)(0),             // 1: grpc.gateway.examples.internal.pathenum.snake_case_for_import
	(MessagePathEnum_NestedPathEnum)(0), // 2: grpc.gateway.examples.internal.pathenum.MessagePathEnum.NestedPathEnum
	(*MessagePathEnum)(nil),             // 3: grpc.gateway.examples.internal.pathenum.MessagePathEnum
	(*MessageWithPathEnum)(nil),         // 4: grpc.gateway.examples.internal.pathenum.MessageWithPathEnum
	(*MessageWithNestedPathEnum)(nil),   // 5: grpc.gateway.examples.internal.pathenum.MessageWithNestedPathEnum
}
var file_examples_internal_proto_pathenum_path_enum_proto_depIdxs = []int32{
	0, // 0: grpc.gateway.examples.internal.pathenum.MessageWithPathEnum.value:type_name -> grpc.gateway.examples.internal.pathenum.PathEnum
	2, // 1: grpc.gateway.examples.internal.pathenum.MessageWithNestedPathEnum.value:type_name -> grpc.gateway.examples.internal.pathenum.MessagePathEnum.NestedPathEnum
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_examples_internal_proto_pathenum_path_enum_proto_init() }
func file_examples_internal_proto_pathenum_path_enum_proto_init() {
	if File_examples_internal_proto_pathenum_path_enum_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*MessagePathEnum); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*MessageWithPathEnum); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_examples_internal_proto_pathenum_path_enum_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*MessageWithNestedPathEnum); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_examples_internal_proto_pathenum_path_enum_proto_rawDesc,
			NumEnums:      3,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_examples_internal_proto_pathenum_path_enum_proto_goTypes,
		DependencyIndexes: file_examples_internal_proto_pathenum_path_enum_proto_depIdxs,
		EnumInfos:         file_examples_internal_proto_pathenum_path_enum_proto_enumTypes,
		MessageInfos:      file_examples_internal_proto_pathenum_path_enum_proto_msgTypes,
	}.Build()
	File_examples_internal_proto_pathenum_path_enum_proto = out.File
	file_examples_internal_proto_pathenum_path_enum_proto_rawDesc = nil
	file_examples_internal_proto_pathenum_path_enum_proto_goTypes = nil
	file_examples_internal_proto_pathenum_path_enum_proto_depIdxs = nil
}
