/*
 * A Bit of Everything
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * API version: 1.0
 * Contact: none@example.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package abe
// ExamplepbsnakeCase0Enum : - value_e: buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE  - value_f: buf:lint:ignore ENUM_VALUE_UPPER_SNAKE_CASE
type ExamplepbsnakeCase0Enum string

// List of examplepbsnake_case_0_enum
const (
	E_ExamplepbsnakeCase0Enum ExamplepbsnakeCase0Enum = "value_e"
	F_ExamplepbsnakeCase0Enum ExamplepbsnakeCase0Enum = "value_f"
)
